SWDEV-341956 - update HIP Dtest with correct coordinates (#2755)

Change-Id: Iaccc4251a984e690d680ce884c6bfcc1093703af

[ROCm/hip commit: 2667f3e225]
This commit is contained in:
ROCm CI Service Account
2022-06-30 13:29:27 +05:30
committed by GitHub
parent 47a1198e18
commit da2888b9c4
11 changed files with 24 additions and 24 deletions
@@ -36,7 +36,7 @@ static void callee(uint64_t* output, uint64_t* input) {
}
__global__ void kernel(uint64_t fptr, uint64_t* retval0, uint64_t* retval1) {
uint tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint tid = threadIdx.x + blockIdx.x * blockDim.x;
uint64_t arg0 = (uint64_t)fptr;
uint64_t arg1 = tid;
uint64_t arg2 = 42;
@@ -43,7 +43,7 @@ void print_things_0(ulong* output, ulong* input) {
}
__global__ void kernel0(ulong fptr, ulong* retval) {
uint tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint tid = threadIdx.x + blockIdx.x * blockDim.x;
ulong arg0 = fptr;
const char* str = "(%lu -> %lu)\n";
@@ -77,7 +77,7 @@ void print_things_1(ulong* output, const ulong* input) {
}
__global__ void kernel1(ulong fptr, ulong name, ulong* retval) {
uint tid = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
uint tid = threadIdx.x + blockIdx.x * blockDim.x;
ulong arg0 = fptr;
ulong arg1 = name;
ulong arg2 = tid;